@@ -7,20 +7,19 @@
 
 module Command.Untrust where
 
+import Common.Annex
 import Command
 import qualified Remote
-import UUID
-import Trust
-import Messages
+import Logs.Trust
 
-command :: [Command]
-command = [repoCommand "untrust" (paramRepeating paramRemote) seek
+def :: [Command]
+def = [command "untrust" (paramRepeating paramRemote) seek
 	"do not trust a repository"]
 
 seek :: [CommandSeek]
 seek = [withWords start]
 
-start :: CommandStartWords
+start :: [String] -> CommandStart
 start ws = do
 	let name = unwords ws
 	showStart "untrust" name
